Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(253)

Unified Diff: third_party/WebKit/Source/platform/heap/PagePool.h

Issue 1754183002: Rename BaseHeap to BaseArena (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/heap/PagePool.h
diff --git a/third_party/WebKit/Source/platform/heap/PagePool.h b/third_party/WebKit/Source/platform/heap/PagePool.h
index 34633ed4db49a51d3b6acd78c9fd154f6446a75b..f09d1e593b81d5c78c2d2eebaa19ddb187fa0ba4 100644
--- a/third_party/WebKit/Source/platform/heap/PagePool.h
+++ b/third_party/WebKit/Source/platform/heap/PagePool.h
@@ -20,7 +20,7 @@ class PagePool {
protected:
PagePool()
{
- for (int i = 0; i < BlinkGC::NumberOfHeaps; ++i)
+ for (int i = 0; i < BlinkGC::NumberOfArenas; ++i)
m_pool[i] = nullptr;
}
@@ -36,14 +36,14 @@ protected:
PoolEntry* next;
};
- PoolEntry* m_pool[BlinkGC::NumberOfHeaps];
+ PoolEntry* m_pool[BlinkGC::NumberOfArenas];
};
// Once pages have been used for one type of thread heap they will never be
// reused for another type of thread heap. Instead of unmapping, we add the
// pages to a pool of pages to be reused later by a thread heap of the same
// type. This is done as a security feature to avoid type confusion. The
// heaps are type segregated by having separate thread heaps for different
// types of objects. Holding on to pages ensures that the same virtual address
// space cannot be used for objects of another type than the type contained
// in this page to begin with.
@@ -54,7 +54,7 @@ public:
PageMemory* takeFreePage(int);
private:
- Mutex m_mutex[BlinkGC::NumberOfHeaps];
+ Mutex m_mutex[BlinkGC::NumberOfArenas];
};
class OrphanedPagePool : public PagePool<BasePage> {
« no previous file with comments | « third_party/WebKit/Source/platform/heap/MarkingVisitorImpl.h ('k') | third_party/WebKit/Source/platform/heap/PagePool.cpp » ('j') | no next file with comments »
@@ -36,14 +36,14 @@ protected:
// pages to a pool of pages to be reused later by a thread heap of the same
// type. This is done as a security feature to avoid type confusion. The
-// heaps are type segregated by having separate thread heaps for different
+// heaps are type segregated by having separate thread arenas for different
// types of objects. Holding on to pages ensures that the same virtual address
// space cannot be used for objects of another type than the type contained

Powered by Google App Engine
This is Rietveld 408576698